[compiler-rt] 8a386b2 - [sanitizer] Fix text in error message

Vitaly Buka via llvm-commits llvm-commits at lists.llvm.org
Sat Mar 11 13:48:10 PST 2023


Author: Vitaly Buka
Date: 2023-03-11T13:40:42-08:00
New Revision: 8a386b22509d4ad1fccef3cf8fb42c887ec29874

URL: https://github.com/llvm/llvm-project/commit/8a386b22509d4ad1fccef3cf8fb42c887ec29874
DIFF: https://github.com/llvm/llvm-project/commit/8a386b22509d4ad1fccef3cf8fb42c887ec29874.diff

LOG: [sanitizer] Fix text in error message

Added: 
    

Modified: 
    compiler-rt/lib/sanitizer_common/sanitizer_common.cpp

Removed: 
    


################################################################################
diff  --git a/compiler-rt/lib/sanitizer_common/sanitizer_common.cpp b/compiler-rt/lib/sanitizer_common/sanitizer_common.cpp
index 1a74b22610772..79b7748b8f6e8 100644
--- a/compiler-rt/lib/sanitizer_common/sanitizer_common.cpp
+++ b/compiler-rt/lib/sanitizer_common/sanitizer_common.cpp
@@ -66,8 +66,8 @@ void NORETURN ReportMunmapFailureAndDie(void *addr, uptr size, error_t err,
   static int recursion_count;
   if (raw_report || recursion_count) {
     // If raw report is requested or we went into recursion just die.  The
-    // Report() and CHECK calls below may call mmap recursively and fail.
-    RawWrite("ERROR: Failed to mmap\n");
+    // Report() and CHECK calls below may call munmap recursively and fail.
+    RawWrite("ERROR: Failed to munmap\n");
     Die();
   }
   recursion_count++;


        


More information about the llvm-commits mailing list